# ChronoXtract

ChronoXtract is a powerful library designed to extract features from your time series/sequential data.

> Current version is V0.0.1

## Features Available

- Calculates statistical features from the time series data.
  - Mean, Median, Mode, Variance, Standard Deviation, Skewness, Kurtosis, Minimum, Maximum, Quantiles, Sum, Absolute Energy.

## Installation

To install ChronoXtract, use pip:

```sh
pip install chronoxtract
```

## Usage

Here's a quick example to get you started:

```python
from chronoxtract import time_series_summary

a = [i for i in range(100000)]


print(time_series_summary(a))
```

## Documentation

Coming Soon

## Contributing

We welcome contributions! Please see our [contributing guidelines](https://example.com/contributing) for more details.

## License

This project is licensed under the MIT License. See the [LICENSE](LICENSE) file for more information.

## Contact

For any questions or feedback, please contact us at [kumaramanasci@gmail.com](mailto:kumaramanasci@gmail.com).
